## Deprecated functions

```{eval-rst}
.. currentmodule:: scanpy
```

```{eval-rst}
.. autosummary::
   :nosignatures:
   :toctree: ../generated/

   pp.filter_genes_dispersion
   pp.normalize_per_cell
   pp.subsample
   pl.filter_genes_dispersion
```
